mirror_dict
-----------

Package `mirror_dict` provides a mapping that returns the key if no value is found.

This isn't particularly difficult, but has been useful enough in a handful of occasions to warrant a package.
